@@ -1,6 +1,7 @@
 package api
 
 import (
+	"syscall"
 	"time"
 )
 
@@ -729,6 +730,10 @@ type DeployImageInput struct {
 	Strategy   *string     `json:"strategy"`
 }
 
+type Signal struct {
+	syscall.Signal
+}
+
 type Service struct {
 	Description     string        `json:"description"`
 	Protocol        string        `json:"protocol,omitempty"`
@@ -1189,6 +1194,38 @@ type Machine struct {
 	CreatedAt time.Time
 }
 
+type Condition struct {
+	Equal    interface{} `json:"equal,omitempty"`
+	NotEqual interface{} `json:"not_equal,omitempty"`
+}
+
+type Filters struct {
+	AppName      string               `json:"app_name"`
+	MachineState []Condition          `json:"machine_state"`
+	Meta         map[string]Condition `json:"meta"`
+}
+
+type V1Machine struct {
+	ID    string `json:"id"`
+	Name  string `json:"name"`
+	AppID int    `json:"app_id"`
+
+	State string `json:"state"`
+
+	// InstanceID is unique for each version of the machine
+	InstanceID string `json:"instance_id"`
+
+	// PrivateIP is the internal 6PN address of the machine.
+	PrivateIP string `json:"private_ip"`
+}
+
+type V1MachineStop struct {
+	ID      string        `json:"id"`
+	Signal  Signal        `json:"signal,omitempty"`
+	Timeout time.Duration `json:"timeout,omitempty"`
+	Filters *Filters      `json:"filters,omitempty"`
+}
+
 type MachineIP struct {
 	Family   string
 	Kind     string
